@@ -2,18 +2,18 @@
 #######################################################################
 """Mix-in class for the IDocShort and IDocBody view
 
-$Id: abstractannotation.py 51952 2008-10-23 20:14:11Z cray $
+$Id: abstractannotation.py 52410 2009-01-30 11:33:29Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51952 $"
+__version__ = "$Revision: 52410 $"
 
 from zope.interface import Interface
 from ng.app.converter.object2psadapter.interfaces import IPropertySheet
 from ng.content.article.interfaces import IDocShort
 from zope.location import location         
 from zope.security.proxy import removeSecurityProxy        
-from ng.skin.base.page.contentlet.viewletbase import ViewletBase
+from ng.lib.viewletbase import ViewletBase
 
 class Proxy(object) :
 
@@ -21,7 +21,6 @@ class Proxy(object) :
         self.ob = ob
         self.doc = IDocShort(ob)
         self.ps = IPropertySheet(self.doc)
-        print self.ps 
                                 
     @property
     def abstract(self) :
