@@ -2,13 +2,13 @@
 #######################################################################
 """MixIn class for content viewlet
 
-$Id: content.py 51952 2008-10-23 20:14:11Z cray $
+$Id: content.py 52240 2008-12-29 00:25:58Z cray $
 """
 __author__  = "Andrey Orlov"
 __license__ = "GPL"
-__version__ = "$Revision: 51952 $"
+__version__ = "$Revision: 52240 $"
 
-from ng.skin.base.page.contentlet.viewletbase import ViewletBase
+from ng.lib.viewletbase import ViewletBase
 
 class Content(ViewletBase) :
     """ Content """
